@@ -142,6 +142,15 @@ pub fn svc_is_active() -> bool {
     ACTIVE.load(atomic::Ordering::SeqCst)
 }
 
+#[macro_export]
+macro_rules! need_ready {
+    () => {
+        if !svc_is_active() {
+            return;
+        }
+    };
+}
+
 #[macro_export]
 macro_rules! rpc_need_ready {
     () => {
@@ -309,9 +318,18 @@ pub fn start_signal_handlers() {
             });
         }};
     }
+    macro_rules! ignore_signal {
+        ($signal: expr) => {{
+            tokio::spawn(async move {
+                loop {
+                    signal($signal).unwrap().recv().await;
+                }
+            });
+        }};
+    }
     handle_signal!(SignalKind::terminate());
     handle_signal!(SignalKind::hangup());
-    handle_signal!(SignalKind::interrupt());
+    ignore_signal!(SignalKind::interrupt());
 }
 
 fn process_initial(buf: &[u8]) -> EResult<services::Initial> {
